@@ -12,7 +12,8 @@ from peek_platform.build_common.BuilderABC import BuilderABC
 from peek_platform.build_frontend.FrontendFileSync import FrontendFileSync
 from peek_platform.file_config.PeekFileConfigFrontendDirMixin import \
     PeekFileConfigFrontendDirMixin
-from peek_platform.file_config.PeekFileConfigOsMixin import PeekFileConfigOsMixin
+from peek_platform.file_config.PeekFileConfigOsMixin import \
+    PeekFileConfigOsMixin
 from peek_plugin_base.PluginPackageFileConfig import PluginPackageFileConfig
 
 logger = logging.getLogger(__name__)
@@ -21,33 +22,32 @@ logger = logging.getLogger(__name__)
 logging.getLogger("watchdog.observers.inotify_buffer").setLevel(logging.INFO)
 
 PluginDetail = namedtuple("PluginDetail",
-                          ["pluginRootDir",
-                           "pluginName",
-                           "pluginTitle",
-                           "appDir",
-                           "appModule",
-                           "cfgDir",
-                           "cfgModule",
-                           "moduleDir",
-                           "assetDir",
-                           "rootModules",
-                           "rootServices",
-                           "rootComponents",
-                           "icon",
-                           "homeLinkText",
-                           "showHomeLink",
-                           "showInTitleBar",
-                           "titleBarLeft",
-                           "titleBarText",
-                           "configLinkPath"])
+    ["pluginRootDir",
+     "pluginName",
+     "pluginTitle",
+     "appDir",
+     "appModule",
+     "cfgDir",
+     "cfgModule",
+     "moduleDir",
+     "assetDir",
+     "rootModules",
+     "rootServices",
+     "rootComponents",
+     "icon",
+     "homeLinkText",
+     "showHomeLink",
+     "showInTitleBar",
+     "antIcon",
+     "titleBarText",
+     "configLinkPath"])
 
 
 class BuildTypeEnum:
     ELECTRON = "ELECTRON"
-    WEB_DESKTOP = "WEB_DESKTOP"
-    WEB_MOBILE = "WEB_MOBILE"
+    WEB_OFFICE = "WEB_OFFICE"
+    WEB_FIELD = "WEB_FIELD"
     WEB_ADMIN = "WEB_ADMIN"
-    NATIVE_SCRIPT = "NATIVE_SCRIPT"
 
 
 class FrontendBuilderABC(BuilderABC):
@@ -65,18 +65,18 @@ class FrontendBuilderABC(BuilderABC):
     """
 
     _CFG_KEYS = {
-        BuildTypeEnum.ELECTRON: ["desktop-electron", "desktop"],
-        BuildTypeEnum.WEB_DESKTOP: ["desktop-web", "desktop"],
-        BuildTypeEnum.WEB_MOBILE: ["mobile-web", "mobile"],
-        BuildTypeEnum.NATIVE_SCRIPT: ["mobile-ns", "mobile"],
+        BuildTypeEnum.ELECTRON: ["office-electron", "office"],
+        BuildTypeEnum.WEB_OFFICE: ["office-web", "office"],
+        BuildTypeEnum.WEB_FIELD: ["field-web", "field"],
         BuildTypeEnum.WEB_ADMIN: ["admin"]
     }
 
     def __init__(self, frontendProjectDir: str, platformService: str,
                  buildType: BuildTypeEnum, jsonCfg,
                  loadedPlugins: List):
-        assert platformService in ("peek-mobile", "peek-admin", "peek-desktop"), (
-                "Unexpected service %s" % platformService)
+        assert platformService in (
+            "peek-field-app", "peek-admin-app", "peek-office-app"), (
+            "Unexpected service %s" % platformService)
 
         self._platformService = platformService
         self._buildType = buildType
@@ -115,7 +115,7 @@ class FrontendBuilderABC(BuilderABC):
             if not jsonCfgNode:
                 logger.info("Skipping frontend build for %s,"
                             "missing config section for %s",
-                            plugin.name, self._buildType)
+                    plugin.name, self._buildType)
                 continue
 
             enabled = (jsonCfgNode.enableAngularFrontend(True, require_bool))
@@ -135,7 +135,7 @@ class FrontendBuilderABC(BuilderABC):
             showHomeLink = jsonCfgNode.showHomeLink(True)
             homeLinkText = jsonCfgNode.homeLinkText(plugin.title)
             showInTitleBar = jsonCfgNode.showInTitleBar(False)
-            titleBarLeft = jsonCfgNode.titleBarLeft(False)
+            antIcon = jsonCfgNode.antIcon(None)
             titleBarText = jsonCfgNode.titleBarText(None)
             configLinkPath = jsonCfgNode.configLinkPath(None)
 
@@ -178,24 +178,24 @@ class FrontendBuilderABC(BuilderABC):
 
             pluginDetails.append(
                 PluginDetail(pluginRootDir=plugin.rootDir,
-                             pluginName=plugin.name,
-                             pluginTitle=plugin.title,
-                             appDir=appDir,
-                             appModule=appModule,
-                             cfgDir=cfgDir,
-                             cfgModule=cfgModule,
-                             moduleDir=moduleDir,
-                             assetDir=assetDir,
-                             rootModules=rootModules,
-                             rootServices=rootServices,
-                             rootComponents=rootComponents,
-                             icon=icon,
-                             homeLinkText=homeLinkText,
-                             showHomeLink=showHomeLink,
-                             showInTitleBar=showInTitleBar,
-                             titleBarLeft=titleBarLeft,
-                             titleBarText=titleBarText,
-                             configLinkPath=configLinkPath)
+                    pluginName=plugin.name,
+                    pluginTitle=plugin.title,
+                    appDir=appDir,
+                    appModule=appModule,
+                    cfgDir=cfgDir,
+                    cfgModule=cfgModule,
+                    moduleDir=moduleDir,
+                    assetDir=assetDir,
+                    rootModules=rootModules,
+                    rootServices=rootServices,
+                    rootComponents=rootComponents,
+                    icon=icon,
+                    homeLinkText=homeLinkText,
+                    showHomeLink=showHomeLink,
+                    showInTitleBar=showInTitleBar,
+                    antIcon=antIcon,
+                    titleBarText=titleBarText,
+                    configLinkPath=configLinkPath)
             )
 
         pluginDetails.sort(key=lambda x: x.pluginName)
@@ -226,16 +226,15 @@ class FrontendBuilderABC(BuilderABC):
                 continue
 
             links.append(dict(name=pluginDetail.pluginName,
-                              title=pluginDetail.homeLinkText,
-                              resourcePath="/%s" % pluginDetail.pluginName,
-                              pluginIconPath=pluginDetail.icon))
+                title=pluginDetail.homeLinkText,
+                resourcePath="/%s" % pluginDetail.pluginName,
+                pluginIconPath=pluginDetail.icon))
 
         links.sort(key=lambda item: item["title"])
 
         contents = "// This file is auto generated, the git version is blank and .gitignored\n"
         contents += "export const homeLinks = %s;\n" % json.dumps(
             links, sort_keys=True, indent=4, separators=(', ', ': '))
-
         self._writeFileIfRequired(feAppDir, 'plugin-home-links.ts', contents)
 
     def _writePluginConfigLinks(self, feAppDir: str,
@@ -257,9 +256,9 @@ class FrontendBuilderABC(BuilderABC):
                 continue
 
             links.append(dict(name=pluginDetail.pluginName,
-                              title=pluginDetail.homeLinkText,
-                              resourcePath="/%s_cfg/" % pluginDetail.pluginName,
-                              pluginIconPath=pluginDetail.icon))
+                title=pluginDetail.homeLinkText,
+                resourcePath="/%s_cfg/" % pluginDetail.pluginName,
+                pluginIconPath=pluginDetail.icon))
 
         links.sort(key=lambda item: item["title"])
 
@@ -279,7 +278,7 @@ class FrontendBuilderABC(BuilderABC):
             {
                 plugin : "peek_plugin_noop",
                 text: "Noop",
-                left: false,
+                antIcon: "smile",
                 resourcePath: "/peek_plugin_noop/home_icon.png",
                 badgeCount : null
             }
@@ -292,24 +291,25 @@ class FrontendBuilderABC(BuilderABC):
                 continue
 
             links.append(dict(plugin=pluginDetail.pluginName,
-                              text=pluginDetail.titleBarText,
-                              left=pluginDetail.titleBarLeft,
-                              resourcePath="/%s" % pluginDetail.pluginName,
-                              badgeCount=None))
+                text=pluginDetail.titleBarText,
+                antIcon=pluginDetail.antIcon,
+                resourcePath="/%s" % pluginDetail.pluginName,
+                badgeCount=None))
 
         contents = "// This file is auto generated, the git version is blank and .gitignored\n\n"
-        contents += "import { ITitleBarLink } from '@synerty/peek-plugin-base-js'\n\n"
-        contents += "export const titleBarLinks: ITitleBarLink[] = %s;\n" % json.dumps(
+        contents += "import { IHeaderLink } from '@synerty/peek-plugin-base-js'\n\n"
+        contents += "export const titleBarLinks: IHeaderLink[] = %s;\n" % json.dumps(
             links, sort_keys=True, indent=4, separators=(', ', ': '))
 
-        self._writeFileIfRequired(feAppDir, 'plugin-title-bar-links.ts', contents)
+        self._writeFileIfRequired(feAppDir, 'plugin-title-bar-links.ts',
+            contents)
 
     def _writePluginAppRouteLazyLoads(self, feAppDir: str,
                                       pluginDetails: [PluginDetail]) -> None:
         _appRoutesTemplate = dedent("""
             {
                 path: '%s',
-                loadChildren: "%s/%s"
+                loadChildren: "@_peek/%s/%s"
             }""")
 
         routes = []
@@ -332,7 +332,7 @@ class FrontendBuilderABC(BuilderABC):
         _cfgRoutesTemplate = dedent("""
             {
                 path: '%s_cfg',
-                loadChildren: "%s_cfg/%s"
+                loadChildren: "@_peek/%s_cfg/%s"
             }""")
 
         routes = []
@@ -354,14 +354,19 @@ class FrontendBuilderABC(BuilderABC):
                                 pluginDetails: [PluginDetail]) -> None:
 
         # initialise the arrays, and put in the persisted service module
-        imports = ['''import {PluginRootServicePersistentLoadModule} 
-                        from "./plugin-root-services";''']
+        imports = [
+            '''import { PluginRootServicePersistentLoadModule } from "./plugin-root-services"''']
         modules = ['PluginRootServicePersistentLoadModule']
 
         for pluginDetail in pluginDetails:
             for rootModule in pluginDetail.rootModules:
-                filePath = self._makeModuleOrServicePath(pluginDetail, rootModule)
-                imports.append('import {%s} from "%s/%s";'
+                filePath = self._makeModuleOrServicePath(pluginDetail,
+                    rootModule)
+
+                if filePath.startswith("peek_"):
+                    filePath = "@_peek/" + filePath
+
+                imports.append('import { %s } from "%s/%s"'
                                % (rootModule["class"],
                                   filePath,
                                   rootModule["file"]))
@@ -383,14 +388,19 @@ class FrontendBuilderABC(BuilderABC):
         persistentServices = []
         for pluginDetail in pluginDetails:
             for rootService in pluginDetail.rootServices:
-                filePath = self._makeModuleOrServicePath(pluginDetail, rootService)
-                imports.append('import {%s} from "%s/%s";'
+                filePath = self._makeModuleOrServicePath(pluginDetail,
+                    rootService)
+
+                if filePath.startswith("peek_"):
+                    filePath = "@_peek/" + filePath
+
+                imports.append('import { %s } from "%s/%s"'
                                % (rootService["class"],
                                   filePath,
                                   rootService["file"]))
 
                 if rootService["useClassFile"] and rootService["useClassClass"]:
-                    imports.append('import {%s} from "%s/%s";'
+                    imports.append('import { %s } from "%s/%s"'
                                    % (rootService["useClassClass"],
                                       filePath,
                                       rootService["useClassFile"]))
@@ -402,7 +412,9 @@ class FrontendBuilderABC(BuilderABC):
                 elif rootService["useExistingClass"]:
                     services.append(
                         '{provide:%s, useExisting:%s}'
-                        % (rootService["class"], rootService["useExistingClass"])
+                        % (
+                            rootService["class"],
+                            rootService["useExistingClass"])
                     )
 
                 else:
@@ -418,20 +430,18 @@ class FrontendBuilderABC(BuilderABC):
         routeData += "\n];\n"
 
         routeData += '''
-        import {NgModule} from "@angular/core";
+        import { NgModule } from "@angular/core"
 
         @NgModule({
         
         })
         export class PluginRootServicePersistentLoadModule {
-            constructor(%s){
-        
-            }
-        
+            constructor(%s) { }
         }
         ''' % ', '.join(['private _%s:%s' % (s, s) for s in persistentServices])
 
-        self._writeFileIfRequired(feAppDir, 'plugin-root-services.ts', routeData)
+        self._writeFileIfRequired(feAppDir, 'plugin-root-services.ts',
+            routeData)
 
     def _writePluginRootComponents(self, feAppDir: str,
                                    pluginDetails: [PluginDetail]) -> None:
@@ -441,22 +451,22 @@ class FrontendBuilderABC(BuilderABC):
 
         for pluginDetail in pluginDetails:
             for comp in pluginDetail.rootComponents:
-                selectors.append('    <%(s)s></%(s)s>' % dict(s=comp["selector"]))
+                selectors.append(
+                    '    <%(s)s></%(s)s>' % dict(s=comp["selector"]))
 
         html = "<div>\n%s\n</div>\n" % '\n'.join(selectors)
         nsXml = "<StackLayout>\n%s\n</StackLayout>\n" % '\n'.join(selectors)
 
-        if self._buildType == BuildTypeEnum.NATIVE_SCRIPT:
-            self._writeFileIfRequired(feAppDir, 'plugin-root.component.ns.html', nsXml)
-        else:
-            self._writeFileIfRequired(feAppDir, 'plugin-root.component.web.html', html)
+        self._writeFileIfRequired(feAppDir, 'plugin-root.component.web.html',
+            html)
 
     def _syncPluginFiles(self, targetDir: str,
                          pluginDetails: [PluginDetail],
                          attrName: str,
                          preSyncCallback: Optional[Callable[[], None]] = None,
                          postSyncCallback: Optional[Callable[[], None]] = None,
-                         keepCompiledFilePatterns: Optional[Dict[str, List[str]]] = None,
+                         keepCompiledFilePatterns: Optional[
+                             Dict[str, List[str]]] = None,
                          excludeFilesRegex=(),
                          isCfgDir=False) -> None:
         cfgPostfix = "_cfg"
@@ -468,7 +478,8 @@ class FrontendBuilderABC(BuilderABC):
         currentItems = set()
         createdItems = set()
         for item in os.listdir(targetDir):
-            if not item.startswith("peek_plugin_") or item.startswith("peek_core_"):
+            if not item.startswith("peek_plugin_") or item.startswith(
+                "peek_core_"):
                 continue
 
             if isCfgDir:
@@ -486,21 +497,22 @@ class FrontendBuilderABC(BuilderABC):
             srcDir = os.path.join(pluginDetail.pluginRootDir, frontendDir)
             if not os.path.exists(srcDir):
                 logger.warning("%s FE dir %s doesn't exist",
-                               pluginDetail.pluginName, frontendDir)
+                    pluginDetail.pluginName, frontendDir)
                 continue
 
             if isCfgDir:
                 createdItems.add(pluginDetail.pluginName + cfgPostfix)
-                linkPath = os.path.join(targetDir, pluginDetail.pluginName + cfgPostfix)
+                linkPath = os.path.join(targetDir,
+                    pluginDetail.pluginName + cfgPostfix)
             else:
                 createdItems.add(pluginDetail.pluginName)
                 linkPath = os.path.join(targetDir, pluginDetail.pluginName)
 
             self.fileSync.addSyncMapping(srcDir, linkPath,
-                                         keepCompiledFilePatterns=keepCompiledFilePatterns,
-                                         preSyncCallback=preSyncCallback,
-                                         postSyncCallback=postSyncCallback,
-                                         excludeFilesRegex=excludeFilesRegex)
+                keepCompiledFilePatterns=keepCompiledFilePatterns,
+                preSyncCallback=preSyncCallback,
+                postSyncCallback=postSyncCallback,
+                excludeFilesRegex=excludeFilesRegex)
 
         # Delete the items that we didn't create
         for item in currentItems - createdItems:
@@ -532,14 +544,14 @@ class FrontendBuilderABC(BuilderABC):
                 continue
 
             moduleDir = os.path.join(pluginDetail.pluginRootDir,
-                                     pluginDetail.moduleDir)
+                pluginDetail.moduleDir)
 
             name = "%s/%s" % (serviceName, pluginDetail.pluginName)
             dependencies[name] = "file:///" + moduleDir.replace("\\", '/')
 
         contents = json.dumps(jsonData, sort_keys=True, indent=2,
-                              separators=(',', ': '))
+            separators=(',', ': '))
 
         self._writeFileIfRequired(os.path.dirname(targetJson),
-                                  os.path.basename(targetJson),
-                                  contents)
+            os.path.basename(targetJson),
+            contents)
