@@ -3,8 +3,13 @@ import os
 from abc import ABCMeta
 from typing import Optional
 
-from jsoncfg.value_mappers import require_string, RequireType, require_list, require_bool, \
-    require_integer
+from jsoncfg.value_mappers import (
+    require_string,
+    RequireType,
+    require_list,
+    require_bool,
+    require_integer,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -55,7 +60,7 @@ class PeekFileConfigPlatformMixin(metaclass=ABCMeta):
     @property
     def loggingLogToSyslogFacility(self) -> str:
         with self._cfg as c:
-            return c.logging.syslog.logToSysloyProtocol('user', require_string)
+            return c.logging.syslog.logToSysloyProtocol("user", require_string)
 
     @property
     def twistedThreadPoolSize(self) -> int:
@@ -79,14 +84,14 @@ class PeekFileConfigPlatformMixin(metaclass=ABCMeta):
     # --- Platform Tmp Path
     @property
     def tmpPath(self):
-        default = os.path.join(self._homePath, 'tmp')
+        default = os.path.join(self._homePath, "tmp")
         with self._cfg as c:
             return self._chkDir(c.disk.tmp(default, require_string))
 
     # --- Platform Software Path
     @property
     def platformSoftwarePath(self):
-        default = os.path.join(self._homePath, 'platform_software')
+        default = os.path.join(self._homePath, "platform_software")
         with self._cfg as c:
             return self._chkDir(c.platform.softwarePath(default, require_string))
 
@@ -94,7 +99,7 @@ class PeekFileConfigPlatformMixin(metaclass=ABCMeta):
     @property
     def platformVersion(self):
         with self._cfg as c:
-            return c.platform.version('0.0.0', require_string)
+            return c.platform.version("0.0.0", require_string)
 
     @platformVersion.setter
     def platformVersion(self, value):
@@ -104,13 +109,13 @@ class PeekFileConfigPlatformMixin(metaclass=ABCMeta):
     # --- Plugin Software Path
     @property
     def pluginSoftwarePath(self):
-        default = os.path.join(self._homePath, 'plugin_software')
+        default = os.path.join(self._homePath, "plugin_software")
         with self._cfg as c:
             return self._chkDir(c.plugin.softwarePath(default, require_string))
 
     # --- Plugin Data Path
     def pluginDataPath(self, pluginName):
-        default = os.path.join(self._homePath, 'plugin_data')
+        default = os.path.join(self._homePath, "plugin_data")
 
         with self._cfg as c:
             pluginData = c.plugin.dataPath(default, require_string)
@@ -119,7 +124,7 @@ class PeekFileConfigPlatformMixin(metaclass=ABCMeta):
 
     # --- Plugin Software Version
     def pluginVersion(self, pluginName):
-        """ Plugin Version
+        """Plugin Version
 
         The last version that we know about
         """
